<?php 
/*
	* Name: WooCommerce Hook
	* Develop: SmartAddons
*/

/*
** Add WooCommerce support
*/
add_theme_support( 'woocommerce' );

function market_custom_product_scripts(){
	wp_dequeue_script('wc-add-to-cart-variation');	
	wp_dequeue_script('wc-single-product');
	wp_deregister_script('wc-add-to-cart-variation');
	wp_deregister_script('wc-single-product');
	wp_enqueue_script( 'wc-single-product', get_template_directory_uri() . '/js/woocommerce/single-product.min.js', array( 'jquery' ), null, true );
	wp_enqueue_script( 'wc-add-to-cart-variation', get_template_directory_uri() . '/js/woocommerce/add-to-cart-variation.min.js', array( 'jquery', 'wp-util' ),null, true  );
}
add_action( 'wp_enqueue_scripts', 'market_custom_product_scripts', 110 );


/*
** WooCommerce Compare Version
*/
if( !function_exists( 'sw_woocommerce_version_check' ) ) :
	function sw_woocommerce_version_check( $version = '3.0' ) {
		global $woocommerce;
		if( version_compare( $woocommerce->version, $version, ">=" ) ) {
			return true;
		}else{
			return false;
		}
	}
endif;

/*
** Add filter category
*/
add_filter( 'wp_list_categories', 'market_list_categories' );
function market_list_categories( $output ){
	$output = preg_replace('~\((\d+)\)(?=\s*+<)~', '<span class="number-count">$1</span>', $output);
	return $output;
}

/*
** Minicart via Ajax
*/
add_action( 'wp', 'market_cart_filter' );
function market_cart_filter(){
	$market_page_header = ( get_post_meta( get_the_ID(), 'page_header_style', true ) != '' ) ? get_post_meta( get_the_ID(), 'page_header_style', true ) : market_options()->getCpanelValue('header_style');
	$filter = sw_woocommerce_version_check( $version = '3.0.3' ) ? 'woocommerce_add_to_cart_fragments' : 'add_to_cart_fragments';
	if( $market_page_header == 'style5' ):
		add_filter($filter, 'market_add_to_cart_fragment_style2', 100);
	else :
		add_filter($filter, 'market_add_to_cart_fragment', 100);
	endif;
}

function market_add_to_cart_fragment_style2( $fragments ) { 
	ob_start();
		get_template_part( 'woocommerce/minicart-ajax' );
		$fragments['.market-minicart'] = ob_get_clean();
			return $fragments;		
}

function market_add_to_cart_fragment( $fragments ) { 
	get_template_part( 'woocommerce/minicart-ajax-style1' ); 
	$fragments['.market-minicart-style1'] = ob_get_clean();
	return $fragments;		
}

/*
** Remove WooCommerce breadcrumb
*/
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );

/*
** Add second thumbnail loop product
*/
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );
add_action( 'woocommerce_before_shop_loop_item_title', 'market_woocommerce_template_loop_product_thumbnail', 10 );

function market_product_thumbnail( $size = 'shop_single', $placeholder_width = 0, $placeholder_height = 0  ) {
	global $product, $post;
	$html = '';
	$gallery = get_post_meta($post->ID, '_product_image_gallery', true);
	$attachment_image = '';
	if( !empty( $gallery ) ) {
		$gallery 					= explode( ',', $gallery );
		$first_image_id 	= $gallery[0];
		$attachment_image = wp_get_attachment_image( $first_image_id , $size, false, array('class' => 'hover-image back') );
	}

	$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), '' );
	$html .= '<a href="'.get_permalink( $post->ID ).'">';
	if ( has_post_thumbnail( $post->ID ) ){
		if( $attachment_image ){			
			$html .= '<div class="product-thumb-hover">';
			$html .= (get_the_post_thumbnail( $post->ID, $size )) ? get_the_post_thumbnail( $post->ID, $size ): '<img src="'.get_template_directory_uri().'/assets/img/placeholder/'.$size.'.png" alt="">';
			$html .= $attachment_image;
			$html .= '</div>';				
		}else{
			$html .= ( get_the_post_thumbnail( $post->ID, $size ) ) ? get_the_post_thumbnail( $post->ID, $size ): '<img src="'.get_template_directory_uri().'/assets/img/placeholder/'.$size.'.png" alt="">';
		}			
	}else{
		$html .= '<img src="'.get_template_directory_uri().'/assets/img/placeholder/'.$size.'.png" alt="No thumb">';		
	}
	$html .= '</a>';	
	$html .= market_quickview();
	return $html;
}

function market_woocommerce_template_loop_product_thumbnail(){
	echo market_product_thumbnail();
}

/*
** Filter order
*/
function market_addURLParameter( $url, $paramName, $paramValue ) {
	$url_data = parse_url($url);
	if(!isset($url_data["query"]))
		$url_data["query"]="";

	$params = array();
	parse_str($url_data['query'], $params);
	$params[$paramName] = $paramValue;
	$url_data['query'] = http_build_query($params);
	return market_build_url( $url_data );
}

/*
** Build url 
*/
function market_build_url($url_data) {
	$url="";
	if(isset($url_data['host']))
	{
		$url .= $url_data['scheme'] . '://';
		if (isset($url_data['user'])) {
			$url .= $url_data['user'];
			if (isset($url_data['pass'])) {
				$url .= ':' . $url_data['pass'];
			}
			$url .= '@';
		}
		$url .= $url_data['host'];
		if (isset($url_data['port'])) {
			$url .= ':' . $url_data['port'];
		}
	}
	if (isset($url_data['path'])) {
		$url .= $url_data['path'];
	}
	if (isset($url_data['query'])) {
		$url .= '?' . $url_data['query'];
	}
	if (isset($url_data['fragment'])) {
		$url .= '#' . $url_data['fragment'];
	}
	return $url;
}

remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );

add_action( 'woocommerce_before_shop_loop', 'market_viewmode_wrapper_start', 5 );
add_action( 'woocommerce_before_shop_loop', 'market_viewmode_wrapper_end', 50 );
add_action( 'woocommerce_before_shop_loop', 'market_woocommerce_catalog_ordering', 30 );
add_action( 'woocommerce_before_shop_loop', 'market_woocommerce_pagination', 35 );
add_action( 'woocommerce_before_shop_loop','market_woommerce_view_mode_wrap',15 );
add_action( 'woocommerce_after_shop_loop', 'market_viewmode_wrapper_start', 5 );
add_action( 'woocommerce_after_shop_loop', 'market_viewmode_wrapper_end', 50 );
add_action( 'woocommerce_after_shop_loop', 'market_woommerce_view_mode_wrap', 6 );
add_action( 'woocommerce_after_shop_loop', 'market_woocommerce_catalog_ordering', 7 );
add_action( 'woocommerce_after_shop_loop', 'market_woocommerce_pagination', 8 );

remove_action( 'woocommerce_before_shop_loop', 'wc_print_notices', 10 );
add_action('woocommerce_message','wc_print_notices', 10);
function market_viewmode_wrapper_start(){
	echo '<div class="products-nav clearfix">';
}
function market_viewmode_wrapper_end(){
	echo '</div>';
}
function market_woommerce_view_mode_wrap () {
	$html='<div class="view-mode-wrap pull-left clearfix">
	<div class="view-mode">
		<a href="javascript:void(0)" class="grid-view active" title="'. esc_attr__('Grid view', 'sw-market').'"><span>'. esc_html__('Grid view', 'sw-market').'</span></a>
		<a href="javascript:void(0)" class="list-view" title="'. esc_attr__('List view', 'sw-market') .'"><span>'.esc_html__('List view', 'sw-market').'</span></a>
	</div>	
</div>';
echo $html;
}

/*
** Pagination
*/
function market_woocommerce_pagination() {
	global $wp_query;
	$term 		= get_queried_object();
	$parent_id 	= empty( $term->term_id ) ? 0 : $term->term_id;
	$product_categories = get_categories( apply_filters( 'woocommerce_product_subcategories_args', array(
		'parent'       => $parent_id,
		'menu_order'   => 'ASC',
		'hide_empty'   => 0,
		'hierarchical' => 1,
		'taxonomy'     => 'product_cat',
		'pad_counts'   => 1
		) ) );
	if ( $product_categories ) {
		if ( is_product_category() ) {
			$display_type = get_woocommerce_term_meta( $term->term_id, 'display_type', true );

			switch ( $display_type ) {
				case 'subcategories' :
				$wp_query->post_count    = 0;
				$wp_query->max_num_pages = 0;
				break;
				case '' :
				if ( get_option( 'woocommerce_category_archive_display' ) == 'subcategories' ) {
					$wp_query->post_count    = 0;
					$wp_query->max_num_pages = 0;
				}
				break;
			}
		}

		if ( is_shop() && get_option( 'woocommerce_shop_page_display' ) == 'subcategories' ) {
			$wp_query->post_count    = 0;
			$wp_query->max_num_pages = 0;
		}
	}
	if ( $wp_query->max_num_pages <= 1 ) {
		return;
	}
	
	ob_start();
	?>
	<nav class="woocommerce-pagination pull-right clearfix">
		<?php
		echo paginate_links( apply_filters( 'woocommerce_pagination_args', array(
			'base'         => esc_url_raw( str_replace( 999999999, '%#%', remove_query_arg( 'add-to-cart', get_pagenum_link( 999999999, false ) ) ) ),
			'format'       => '',
			'add_args'     => '',
			'current'      => max( 1, get_query_var( 'paged' ) ),
			'total'        => $wp_query->max_num_pages,
			'prev_text'    => '&larr;',
			'next_text'    => '&rarr;',
			'type'         => 'list',
			'end_size'     => 3,
			'mid_size'     => 3
			) ) );
			?>
		</nav>
		<?php 
		$content = ob_get_clean();
		echo $content;
	}

	function market_woocommerce_catalog_ordering() {
		parse_str($_SERVER['QUERY_STRING'], $params);
		$query_string 	= '?'.$_SERVER['QUERY_STRING'];
		$option_number 	=  market_options()->getCpanelValue( 'product_number' );

		if( $option_number ) {
			$per_page = $option_number;
		} else {
			$per_page = 12;
		}

		$pob = !empty( $params['orderby'] ) ? $params['orderby'] : get_option( 'woocommerce_default_catalog_orderby' );
		$po  = !empty($params['product_order'])  ? $params['product_order'] : 'asc';
		$pc  = !empty($params['product_count']) ? $params['product_count'] : $per_page;

		$html = '';
		$html .= '<div class="catalog-ordering pull-left">';

		$html .= '<div class="orderby-order-container clearfix">';
		$html .= '<div class="orderby-sort-name">';
		$html .= '<span>'.esc_html__('Sort by', 'sw-market').'</span>';
		$html .= '<ul class="orderby order-dropdown pull-left">';
		$html .= '<li>';
		$html .= '<span class="current-li"><span class="current-li-content"><a>'.esc_html__('Default', 'sw-market').'</a></span></span>'; $html .= '<ul>';
		$html .= '<li class="'.( ( $pob == 'menu_order' ) ? 'current': '' ).'"><a href="'.market_addURLParameter( $query_string, 'orderby', 'menu_order' ).'">' . esc_html__( 'Default', 'sw-market' ) . '</a></li>';
		$html .= '<li class="'.( ( $pob == 'popularity' ) ? 'current': '' ).'"><a href="'.market_addURLParameter( $query_string, 'orderby', 'popularity' ).'">' . esc_html__( 'Popularity', 'sw-market' ) . '</a></li>';
		$html .= '<li class="'.( ( $pob == 'rating' ) ? 'current': '' ).'"><a href="'.market_addURLParameter( $query_string, 'orderby', 'rating' ).'">' . esc_html__( 'Rating', 'sw-market' ) . '</a></li>';
		$html .= '<li class="'.( ( $pob == 'date' ) ? 'current': '' ).'"><a href="'.market_addURLParameter( $query_string, 'orderby', 'date' ).'">' . esc_html__( 'Date', 'sw-market' ) . '</a></li>';
		$html .= '<li class="'.( ( $pob == 'price' ) ? 'current': '' ).'"><a href="'.market_addURLParameter( $query_string, 'orderby', 'price' ).'">' . esc_html__( 'Price', 'sw-market' ) . '</a></li>';
		$html .= '</ul>';
		$html .= '</div>';
		$html .= '</li>';
		$html .= '</ul>';
		$html .= '<ul class="order pull-left">';
		if($po == 'desc'):
			$html .= '<li class="desc"><a href="'.market_addURLParameter($query_string, 'product_order', 'asc').'"><i class="fa fa-arrow-up"></i></a></li>';
		endif;
		if($po == 'asc'):
			$html .= '<li class="asc"><a href="'.market_addURLParameter($query_string, 'product_order', 'desc').'"><i class="fa fa-arrow-down"></i></a></li>';
		endif;
		$html .= '</ul>';
		$html .= '<div class="product-number pull-left clearfix"><span class="show-product pull-left">'. esc_html__( 'Show', 'sw-market' ) . ' </span>';
		$html .= '<ul class="sort-count order-dropdown pull-left">';
		$html .= '<li>';
		$html .= '<span class="current-li"><a>'. $per_page .'</a></span>';
		$html .= '<ul>';
		$html .= '<li class="'.(($pc == $per_page) ? 'current': '').'"><a href="'.market_addURLParameter($query_string, 'product_count', $per_page).'">'.$per_page.'</a></li>';
		$html .= '<li class="'.(($pc == $per_page*2) ? 'current': '').'"><a href="'.market_addURLParameter($query_string, 'product_count', $per_page*2).'">'.($per_page*2).'</a></li>';
		$html .= '<li class="'.(($pc == $per_page*3) ? 'current': '').'"><a href="'.market_addURLParameter($query_string, 'product_count', $per_page*3).'">'.($per_page*3).'</a></li>';
		$html .= '</ul>';
		$html .= '</li>';
		$html .= '</ul></div>';
		$html .= '</div>';
		$html .= '</div>';

		echo $html;
	}

	add_action('woocommerce_get_catalog_ordering_args', 'market_woocommerce_get_catalog_ordering_args', 20);
	function market_woocommerce_get_catalog_ordering_args($args)
	{
		global $woocommerce;

		parse_str($_SERVER['QUERY_STRING'], $params);
		$orderby_value = !empty( $params['orderby'] ) ? $params['orderby'] : get_option( 'woocommerce_default_catalog_orderby' );
		$pob = $orderby_value;

		$po = !empty($params['product_order'])  ? $params['product_order'] : 'asc';

		switch($po) {
			case 'desc':
			$order = 'desc';
			break;
			case 'asc':
			$order = 'asc';
			break;
			default:
			$order = 'asc';
			break;
		}
		$args['order'] = $order;

		if( $pob == 'rating' ) {
			$args['order']    = $po == 'desc' ? 'desc' : 'asc';
			$args['order']	  = strtoupper( $args['order'] );
		}

		return $args;
	}

	add_filter('loop_shop_per_page', 'market_loop_shop_per_page');
	function market_loop_shop_per_page() {
		parse_str($_SERVER['QUERY_STRING'], $params);
		$option_number =  market_options()->getCpanelValue( 'product_number' );

		if( $option_number ) {
			$per_page = $option_number;
		} else {
			$per_page = 12;
		}

		$pc = !empty($params['product_count']) ? $params['product_count'] : $per_page;
		return $pc;
	}

/* =====================================================================================================
** Product loop content 
===================================================================================================== */
remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );

add_action( 'woocommerce_shop_loop_item_title', 'market_loop_product_title', 10 );
add_action( 'woocommerce_after_shop_loop_item_title', 'market_loop_rating', 5 );
add_action( 'woocommerce_after_shop_loop_item_title', 'market_loop_price', 10 );
add_action( 'woocommerce_after_shop_loop_item_title', 'market_loop_deal', 15 );
add_action( 'woocommerce_after_shop_loop_item_title', 'market_product_description', 11 );
add_action( 'woocommerce_after_shop_loop_item', 'market_product_addcart_start', 1 );
add_action( 'woocommerce_after_shop_loop_item', 'market_product_addcart_mid', 20 );
add_action( 'woocommerce_after_shop_loop_item', 'market_product_addcart_end', 99 );

/*
** Loop Title
*/
function market_loop_product_title(){
	?>
	<h4><a href="<?php the_permalink() ?>" title="<?php the_title_attribute(); ?>"><?php the_title() ?></a></h4>
	<?php
}

/*
** Loop Rating
*/
function market_loop_rating(){
	global $product;
	$rating = $product->get_average_rating();
	?>
	<div class="reviews-content">
		<div class="star"><?php echo ( $rating > 0 ) ? '<span style="width:' .esc_attr( $rating * 13 ) . 'px"></span>' : ''; ?></div>
	</div>
	<?php 
}

/*
** Loop Price
*/
function market_loop_price(){
	global $product;
	$rating = $product->get_average_rating();
	if ( $price_html = $product->get_price_html() ) : ?>
	<div class="item-price"><span><?php echo $price_html; ?></span></div>
<?php endif;
}

/*
** get offset datetime
*/

function market_timezone_offset( $countdown_time ){
	$timeOffset = 0;	
	if( get_option( 'timezone_string' ) != '' ) :
		$timezone = get_option( 'timezone_string' );
	$dateTimeZone = new DateTimeZone( $timezone );
	$dateTime = new DateTime( "now", $dateTimeZone );
	$timeOffset = $dateTimeZone->getOffset( $dateTime );
	else :
		$dateTime = get_option( 'gmt_offset' );
	$dateTime = intval( $dateTime );
	$timeOffset = $dateTime * 3600;
	endif;
	$offset =  ( $timeOffset < 0 ) ? '-' . gmdate( "H:i", abs( $timeOffset ) ) : '+' . gmdate( "H:i", $timeOffset );

	$date = date( 'Y/m/d H:i:s', $countdown_time );
	$date1 = new DateTime( $date );
	$cd_date =  $date1->format('Y-m-d H:i:s') . $offset;
	
	return $cd_date; 
}

/*
** Add page deal to listing
*/
function market_loop_deal(){
	global $sw_countdown, $product, $post;
	$start_time 		= get_post_meta( $post->ID, '_sale_price_dates_from', true );
	$countdown_time = get_post_meta( $post->ID, '_sale_price_dates_to', true );	
	$orginal_price  = get_post_meta( $post->ID, '_regular_price', true );	
	$symboy 				= get_woocommerce_currency_symbol( get_woocommerce_currency() );
	
	if( !empty ($sw_countdown ) ) :
		$offset = market_timezone_offset( $countdown_time );
	?>
	<div class="product-countdown" data-date="<?php echo esc_attr( $offset ); ?>" data-price="<?php echo esc_attr( $symboy.$orginal_price ); ?>" data-starttime="<?php echo esc_attr( $start_time ); ?>" data-cdtime="<?php echo esc_attr( $countdown_time ); ?>" data-id="<?php echo esc_attr( 'product_' . $post->ID ); ?>"></div>
	<?php 
	endif;
}

/*
** Loop Description
*/
function market_product_description(){
	global $post;
	if ( ! $post->post_excerpt ) return;
	
	echo '<div class="item-description">'.wp_trim_words( $post->post_excerpt, 20 ).'</div>';
}

function market_product_addcart_start(){
	echo '<div class="item-bottom clearfix">';
}

function market_product_addcart_end(){
	echo '</div>';
}

function market_product_addcart_mid(){
	global $product, $post;
	$quickview = market_options()->getCpanelValue( 'product_quickview' );

	$html ='';
	$product_id = $post->ID;
	/* compare & wishlist */
	if( class_exists( 'YITH_WCWL' ) ){
		$html .= do_shortcode( "[yith_wcwl_add_to_wishlist]" );
	}
	if( class_exists( 'YITH_WOOCOMPARE' ) ){
		$html .= '<a href="javascript:void(0)" class="compare button" data-product_id="'. $product_id .'" rel="nofollow">'. esc_html__( 'Compare', 'sw-market' ) .'</a>';
	}	
	echo $html;
}

/*
** Filter product category class
*/
add_filter( 'product_cat_class', 'market_product_category_class', 2 );
function market_product_category_class( $classes, $category = null ){
	$market_product_sidebar = market_options()->getCpanelValue('sidebar_product');
	if( $market_product_sidebar == 'left' || $market_product_sidebar == 'right' ){
		$classes[] = 'col-lg-4 col-md-4 col-sm-6 col-xs-6 col-mb-12';
	}else if( $market_product_sidebar == 'lr' ){
		$classes[] = 'col-lg-6 col-md-6 col-sm-6 col-xs-6 col-mb-12';
	}else if( $market_product_sidebar == 'full' ){
		$classes[] = 'col-lg-3 col-md-4 col-sm-6 col-xs-6 col-mb-12';
	}
	return $classes;
}

/*
** attribute for product listing
*/
function market_product_attribute(){
	global $woocommerce_loop, $sw_attribute;
	if( !empty( $sw_attribute ) ) :
		$attribute = explode( ',', $sw_attribute );
	endif;
	$col_lg = ( !empty( $sw_attribute ) ) ? $attribute[0] : market_options()->getCpanelValue('product_col_large');
	$col_md = ( !empty( $sw_attribute ) ) ? $attribute[1] : market_options()->getCpanelValue('product_col_medium');
	$col_sm = ( !empty( $sw_attribute ) ) ? $attribute[2] : market_options()->getCpanelValue('product_col_sm');
	
	$class_col= "item ";
	
	$column1 = 12 / $col_lg;
	$column2 = 12 / $col_md;
	$column3 = 12 / $col_sm;	

	$class_col .= ' col-lg-'.$column1.' col-md-'.$column2.' col-sm-'.$column3.'';

	if( get_option( 'woocommerce_category_archive_display' ) != 'both' && get_option( 'woocommerce_shop_page_display' ) != 'both'  ){ 
		if ( 0 == $woocommerce_loop['loop'] % $col_lg || 1 == $col_lg ) {
			$class_col .= ' clear_lg';
		}
		if ( 0 == $woocommerce_loop['loop'] % $col_md || 1 == $col_md ) {
			$class_col .= ' clear_md';
		}
		if ( 0 == $woocommerce_loop['loop'] % $col_sm || 1 == $col_sm ) {
			$class_col .= ' clear_sm';
		}
	}
	$class_col .= ' col-xs-6';
	
	return $class_col;
}

/*
** Check sidebar 
*/
function market_sidebar_product(){
	$market_sidebar_product = market_options() -> getCpanelValue('sidebar_product');
	if( !is_post_type_archive( 'product' ) && !is_search() && is_product_category() ){
		$market_sidebar_product = ( get_term_meta( get_queried_object()->term_id, 'term_sidebar', true ) != '' ) ? get_term_meta( get_queried_object()->term_id, 'term_sidebar', true ) : market_options()->getCpanelValue('sidebar_product');
	}	
	if( is_singular( 'product' ) ) {
		$market_sidebar_product = ( get_post_meta( get_the_ID(), 'page_sidebar_layout', true ) != '' ) ? get_post_meta( get_the_ID(), 'page_sidebar_layout', true ) : market_options()->getCpanelValue('sidebar_product');
	}
	return $market_sidebar_product;
}

/* ==========================================================================================
	** Single Product
	========================================================================================== */
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_sharing', 50 );
	add_action( 'woocommerce_single_product_summary', 'market_woocommerce_sharing', 21 );

	function market_woocommerce_sharing(){
		$html = market_get_social();
	}

	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
	add_action( 'woocommerce_single_product_summary', 'market_product_excerpt', 20 );

	function market_product_excerpt(){
		global $post;

		if ( ! $post->post_excerpt ) {
			return;
		}
		$html = '';
		$html .= '<div itemprop="description" class="description">';
		$html .= '<h2>'. esc_html__( 'Quick Overview', 'sw-market' ) .'</h2>';
		$html .= apply_filters( 'woocommerce_short_description', $post->post_excerpt );
		$html .= '</div>';
		echo $html;
	}

	add_action( 'woocommerce_before_add_to_cart_button', 'market_single_addcart_wrapper_start', 10 );
	add_action( 'woocommerce_before_add_to_cart_button', 'market_single_quantity_text', 11 );
	add_action( 'woocommerce_after_add_to_cart_button', 'market_single_addcart_wrapper_end', 20 );
	add_action( 'woocommerce_after_add_to_cart_button', 'market_single_addcart', 10 );
	add_action( 'woocommerce_single_variation', 'market_single_addcart_variable', 25 );
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );

	function market_single_addcart_wrapper_start(){
		echo '<div class="product-summary-bottom clearfix">';
	}

	function market_single_quantity_text(){
		echo '<div class="quantity-text pull-left">' . esc_html__( 'Qty', 'sw-market' ) . '</div>';
	}

	function market_single_addcart_wrapper_end(){
		echo "</div>";
	}
// $yith_compares = new YITH_Woocompare_Frontend();
// var_dump( $yith_compares );

	function market_single_addcart(){

		/* compare & wishlist */
		global $product, $yith_woocompare, $post;
		$html = '';
		$product_id = $post->ID;
		$product_type = ( sw_woocommerce_version_check( '3.0' ) ) ? $product->get_type() : $product->product_type;
		if( $product_type != 'variable' ) :
			/* compare & wishlist */
		if( class_exists( 'YITH_WCWL' ) || class_exists( 'YITH_WOOCOMPARE' ) ){
			//$yith_compare = new YITH_Woocompare_Frontend();
			$html .= '<div class="item-bottom">';	
			$html .= '<a href="javascript:void(0)" class="compare button" data-product_id="'. $product_id .'" rel="nofollow">'. esc_html__( 'Compare', 'sw-market' ) .'</a>';
			$html .= do_shortcode( "[yith_wcwl_add_to_wishlist]" );
			$html .= '</div>';
		}
		echo $html;
		endif;
	}

	function market_single_addcart_variable(){
		/* compare & wishlist */
		global $product, $yith_woocompare, $post;
		$html = '';
		$product_id = $post->ID;

		if( class_exists( 'YITH_WCWL' ) || class_exists( 'YITH_WOOCOMPARE' ) ){
			$html .= '<div class="item-bottom">';	
			$html .= '<a href="javascript:void(0)" class="compare button" data-product_id="'. $product_id .'" rel="nofollow">'. esc_html__( 'Compare', 'sw-market' ) .'</a>';
			$html .= do_shortcode( "[yith_wcwl_add_to_wishlist]" );
			$html .= '</div>';
		}
		echo $html;
	}

/* 
** Add Product Tag To Tabs 
*/
add_filter( 'woocommerce_product_tabs', 'market_tab_tag' );
function market_tab_tag($tabs){
	global $post, $product;
	$tag_count = sizeof( get_the_terms( $post->ID, 'product_tag' ) );
	if ( count( $tag_count ) > 1 ) {
		$tabs['product_tag'] = array(
			'title'    => esc_html__( 'Tags', 'sw-market' ),
			'priority' => 11,
			'callback' => 'market_single_product_tab_tag'
			);
	}
	return $tabs;
}
function market_single_product_tab_tag(){
	global $post, $product;
	echo $product->get_tags( ', ', '<span class="tagged_as">' . _n( 'Tag:', 'Tags:', $tag_count, 'sw-market' ) . ' ', '</span>' );
}

/*
**Hook into review for rick snippet
*/
add_action( 'woocommerce_review_before_comment_meta', 'market_title_ricksnippet', 10 ) ;
function market_title_ricksnippet(){
	global $post;
	echo '<span class="hidden" itemprop="itemReviewed" itemscope itemtype="http://schema.org/Thing">
	<span itemprop="name">'. $post->post_title .'</span>
</span>';
}

/*
** Cart cross sell
*/
add_action('woocommerce_cart_collaterals', 'market_cart_collaterals_start', 1 );
add_action('woocommerce_cart_collaterals', 'market_cart_collaterals_end', 11 );
function market_cart_collaterals_start(){
	echo '<div class="products-wrapper">';
}

function market_cart_collaterals_end(){
	echo '</div>';
}

/*
** Set default value for compare and wishlist 
*/
function market_cpwl_init(){
	if( class_exists( 'YITH_WOOCOMPARE' ) ){
		update_option( 'yith_woocompare_compare_button_in_product_page', 'no' );
		update_option( 'yith_woocompare_compare_button_in_products_list', 'no' );
	}
	if( class_exists( 'YITH_WCWL' ) ){
		update_option( 'yith_wcwl_button_position', 'shortcode' );
	}
}
add_action('admin_init','market_cpwl_init');

/*
** Quickview product
*/
add_action( 'wp_ajax_market_quickviewproduct', 'market_quickviewproduct' );
add_action( 'wp_ajax_nopriv_market_quickviewproduct', 'market_quickviewproduct' );
function market_quickviewproduct(){
	
	$productid = ( isset( $_REQUEST["post_id"] ) && $_REQUEST["post_id"] > 0 ) ? $_REQUEST["post_id"] : 0;
	$query_args = array(
		'post_type'	=> 'product',
		'p'	=> $productid
		);
	$outputraw = $output = '';
	$r = new WP_Query( $query_args );
	
	if($r->have_posts()){ 
		while ( $r->have_posts() ){ $r->the_post(); setup_postdata( $r->post );
			global $product;
			ob_start();
			wc_get_template_part( 'content', 'quickview-product' );
			$outputraw = ob_get_contents();
			ob_end_clean();
		}
	}
	$output = preg_replace( array('/\s{2,}/', '/[\t\n]/'), ' ', $outputraw );
	echo $output;
	exit();
}

/*
** Sale label by percentage
*/
function market_label_sales(){
	global $product, $post;
	$forginal_price 	= get_post_meta( $post->ID, '_regular_price', true );	
	$fsale_price 		= get_post_meta( $post->ID, '_sale_price', true );
	if( $fsale_price > 0 && $product->is_on_sale() ){ 
		$sale_off = 100 - ( ( $fsale_price/$forginal_price ) * 100 ); 
		?>
		<div class="sale-off">
			<?php echo '-' . round( $sale_off ).'%';?>
		</div>

		<?php } 
	}

/*
** Check quickview
*/
function market_quickview(){
	global $product, $post;
	$quickview = 1;
	if( function_exists( 'market_options' ) ){
		$quickview = market_options()->getCpanelValue( 'product_quickview' );
	}
	$nonce = wp_create_nonce("market_quickviewproduct_nonce");
	$link = admin_url('admin-ajax.php?ajax=true&amp;action=market_quickviewproduct&amp;post_id='. esc_attr( $post->ID ).'&amp;nonce='.esc_attr( $nonce ) );
	$html = '<a href="'. esc_url( $link ) .'" data-fancybox-type="ajax" class="group fancybox fancybox.ajax">'.apply_filters( 'out_of_stock_add_to_cart_text', esc_html__( 'Quick View ', 'sw-market' ) ).'</a>';	
	return $html;
}
?>